
/** Projet 3ETI - CPE Lyon - 2011-2012 */


#ifndef _INTEGRATEUR_HPP_
#define _INTEGRATEUR_HPP_



namespace cpe
{
  class model;

  /** Machine a etat pour integrer la fonction reccurente */
  class integrateur
  {
  public:

    /** \brief constructeur direct avec mise a zero de la machine a etat 
	\param double dt: periode d'echantillonnage
	\param model mod: le model du composant
    */
    integrateur(double dt,const model& mod);
    
    /** \brief realise une remise a zero de la machine a etat avec i[k-1]=0 et i[k-2]=0*/
    void init();

    /** \brief evalue une etape d'integration et renvoi le courant i[k] etant donné la valeur de u[k] */
    double operator()(double u);
    
  private:
    /** \brief enregistrement en interne de i[k-1] */
    double i_previous;
    /** \brief enregistrement en interne de i[k-2] */
    double i_previous2;
    /** \brief enregistrement en interne de u[k-1] */
    double u_previous;
    /** \brief enregistrement en interne de u[k-2] */
    double u_previous2;

    /** \brief enregistrement en interne de delta_t */
    double dt;

    /** \brief precalcul des coefficients lineaires pour l'integration */
    const double K;
    /** \brief precalcul des coefficients lineaires pour l'integration */
    const double A;
    /** \brief precalcul des coefficients lineaires pour l'integration */
    const double B;
    /** \brief precalcul des coefficients lineaires pour l'integration */
    const double C;
    /** \brief precalcul des coefficients lineaires pour l'integration */
    const double D;
    /** \brief precalcul des coefficients lineaires pour l'integration */
    const double E;


  };
}
#endif
